@@ -26,6 +26,6 @@ def test_read_write():
 
 def test_comp_df():
     df = pd.DataFrame({"a": [1, 1, 2, 2, 1, 3, 4, 4],
-                       "b": ["A", "A", "B", "B", "A", "C", "D", "D"]})
+                       "b": ["A", "A", "B", "B", "A", "C,D", "D C", "D C"]})
     comp_df = lzhw.CompressedDF(df)
-    assert comp_df.compressed[0].decompress() == list(map(str, df.a))
\ No newline at end of file
+    assert comp_df.compressed[1].decompress() == list(map(str, df.b))
\ No newline at end of file
